Sanzang Utils News
==================

1.0.5 (2014-10-02)
------------------
* Makefile dist target now just builds a Python dist.
* Removed superfluous exception handling.
* Updated source code according to pep8 and pep257.
* Documentation fixes and updates.

1.0.4 (2014-09-09)
------------------
* Updated programs for proper universal newline support.
* Fixed makefile logic bug (documentation directory removal).

1.0.3 (2014-08-23)
------------------
* Translation table fields have surrounding whitespace stripped.
* All spaces and tabs will not be removed from table fields.
* Fixed bug in szu-ss so string matching works correctly.
* Minor documentation fixes.

1.0.2 (2014-08-15)
------------------
* Updated szu-ed to print to stderr for any common exceptions.
* Added missing option description for szu-ss.
* Documentation and build system updates and fixes.

1.0.1 (2014-08-11)
------------------
* Tutorial updated to HTML5.
* Documentation copyedits and formatting.
* Added MANIFEST.in to include makefile in the Python package.
* Fixed minor encoding compatibility issues with UTF-8 BOMs.
* Improved szu-ss table-loading code to be more robust.
* Overhauled szu-ss to use buffering -- much more efficient.

1.0.0 (2014-08-10)
------------------
* Initial commit into git.
